/* $Id: ArrowB.h,v 1.5 1999/11/06 05:50:57 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 Copyright (C) 1999       Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_arrowb_h)
#define xarm_arrowb_h

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Primitive.h>

class ArrowButtonClass : public PrimitiveClass {
 protected:
   ArrowButtonClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return xmArrowButtonWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmArrowButton"; }
 public:
   /* callbacks */

   void activateCallback(XtCallbackProc fp, XtPointer data = NULL)   { XARM_SET_CALLBACK(XmNactivateCallback); }
   void armCallback(XtCallbackProc fp, XtPointer data = NULL)        { XARM_SET_CALLBACK(XmNarmCallback); }
   void disarmCallback(XtCallbackProc fp, XtPointer data = NULL)     { XARM_SET_CALLBACK(XmNdisarmCallback); }

   /* resources */
   void arrowDirection(unsigned char val) { XARM_SET_VALUE(XmNarrowDirection); }
   unsigned char arrowDirection() const   { XARM_GET_VALUE(unsigned char, XmNarrowDirection); }
   void multiClick(unsigned char val)     { XARM_SET_VALUE(XmNmultiClick); }
   unsigned char multiClick() const       { XARM_GET_VALUE(unsigned char, XmNmultiClick); }
};

typedef XarmRawWidget<ArrowButtonClass, true> ArrowButton;

#endif
